Procedural macros for hpm-riscv-rt
This crate provides:
#[entry]- Define the program entry point#[pre_init]- Define a pre-initialization function#[fast]- Place functions/statics in ILM/DLM#[external_interrupt]- Define PLIC external interrupt handlers
Attribute Macros
- entry
- Attribute to declare the entry point of the program.
- external_
interrupt - Define an external interrupt handler for HPMicro PLIC.
- fast
- Place a function or static into fast memory (ILM/DLM).
- pre_
init - Attribute to declare a function that runs before RAM is initialized.